{% extends IMAGESTORE_TEMPLATE|default:"base.html" %}
{% load i18n %}

{% block head %}
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}imagestore.css" media="screen" />
{% endblock %}

{% block content %}
{% endblock content %}

{% block content-related %}
        {% block imagestore-info %}
        {% endblock %}
        <div id="controls">
            <ul>
                {% if imagestore_perms.add_image %}
                    <li><a href={% url imagestore:upload %}>{% trans "Upload image" %}</a></li>
                {% endif %}
                {% if imagestore_perms.add_album %}
                    <li><a href={% url imagestore:create-album %}>{% trans "Create new album" %}</a></li>
                {% endif %}
                {% block controls %}
                {% endblock controls %}
            </ul>
        </div>
        {% block imagestore-related %}
        {% endblock %}
{% endblock %}