{% extends "imagestore/base.html" %}

{% load i18n %}
{% load thumbnail %}


{% block title %}
    {% trans "Gallery" %} - {% trans "User" %}: {{ gallery_owner.username }}
{% endblock %}
{% block breadcrumb %}
    {{ block.super }} &#187;
    <a href="{% url imagestore:category-list %}">{% trans "Gallery" %}</a> &#187;
    {{ gallery_owner.username }}
{% endblock breadcrumb %}

{% block content %}
    <h1>{% trans "User" %} - {{ gallery_owner.username }}</h1>
    {% include "imagestore/image-list.html" %}
{% endblock content %}

{% block content-related %}
    {% include "imagestore/tag-cloud.html" %}
{% endblock %}