{% extends "imagestore/base.html" %}

{% load i18n %}

{% block content %}
    <p>{% trans "Are you sure that you would like to delete this image?" %}</p>
    <form method="POST" action=".">
        {% csrf_token %}
        <input type="submit" value="{% trans "Yes" %}" />
    </form>
    <a href="{{ image.get_absolute_url }}">{% trans "No" %}</a>
{% endblock %}