<link rel="stylesheet" href="{{ STATIC_URL }}prettyphoto/css/prettyPhoto.css" type="text/css" media="screen" charset="utf-8" />
<script src="{{ STATIC_URL }}prettyphoto/js/jquery.prettyPhoto.js" type="text/javascript" charset="utf-8"></script>

<script type="text/javascript" charset="utf-8">
    var prettyparams = {
        animation_speed: 'fast',
        slideshow: 3000,
        autoplay_slideshow: false,
        opacity: 0.7,
        show_title: true,
        allow_resize: true,
        default_width: 1000,
        default_height: 344,
        counter_separator_label: '/',
        theme: 'facebook',
        overlay_gallery: true,
        changepicturecallback: function() {$pp_overlay.css({'height':$(document).height()})},
        };
    $(function(){$("a[rel^='gallery-image']").prettyPhoto(prettyparams)});
</script>