{% extends "imagestore/base.html" %}
{% load i18n %}
{% load thumbnail %}

{% block title %}
    {% if category %}
        {{ category.title }}
    {%  else  %}
        {% trans "Gallery" %}
    {% endif %}
{% endblock %}

{% block breadcrumb %}
    {{ block.super }} &#187;
    {% if category %}
        <a href="{% url imagestore-category-list %}">{% trans "Gallery" %}</a>
    {% else %}
        {% trans "Gallery" %}
    {%  endif %}
    {% if category %}
        &#187; {{  category.title }}
    {% endif %}
{% endblock breadcrumb %}

{% block content %}
    {% if category %}
        <h1>{{ category.title }}</h1>
    {% else %}
        <h1>{% trans "Gallery" %}</h1>
    {% endif %}
    <h2>{% trans 'Categories' %}:</h2>
    {% include "imagestore/category-list.html" %}
    {% if not category %} {% trans "All images:" %} {% endif %}
    {% include "imagestore/image-list.html" %}
{% endblock content %}

{% block content-related %}
    {{ block.super }}
    {% include "imagestore/tag-cloud.html" %}
{% endblock %}